diff mbox series

[1/2] toaster/test: bug-fix element click intercepted in browser/test_layerdetails_page.py

Message ID 20231215112337.229815-1-alassane.yattara@savoirfairelinux.com
State New
Headers show
Series [1/2] toaster/test: bug-fix element click intercepted in browser/test_layerdetails_page.py | expand

Commit Message

Alassane Yattara Dec. 15, 2023, 11:23 a.m. UTC
selenium.common.exceptions.ElementClickInterceptedException: Message: element click intercepted

Signed-off-by: Alassane Yattara <alassane.yattara@savoirfairelinux.com>
---
 .../tests/browser/selenium_helpers_base.py    | 29 ++++++++++++-----
 .../tests/browser/test_layerdetails_page.py   | 31 +++++++++++++++----
 2 files changed, 46 insertions(+), 14 deletions(-)
diff --git a/bitbake/lib/toaster/tests/browser/test_layerdetails_page.py b/bitbake/lib/toaster/tests/browser/test_layerdetails_page.py
index 05ee88b019..9deef6709d 100644
--- a/bitbake/lib/toaster/tests/browser/test_layerdetails_page.py
+++ b/bitbake/lib/toaster/tests/browser/test_layerdetails_page.py
@@ -8,6 +8,7 @@ 
 #
 
 from django.urls import reverse
+from selenium.common.exceptions import ElementClickInterceptedException, TimeoutException
 from tests.browser.selenium_helpers import SeleniumTestCase
 
 from orm.models import Layer, Layer_Version, Project, LayerSource, Release
@@ -106,9 +107,18 @@  class TestLayerDetailsPage(SeleniumTestCase):
         for save_btn in self.find_all(".change-btn"):
             save_btn.click()
 
-        self.wait_until_visible("#save-changes-for-switch", poll=3)
-        btn_save_chg_for_switch = self.find("#save-changes-for-switch")
-        self.driver.execute_script("arguments[0].click();", btn_save_chg_for_switch)
+        try:
+            self.wait_until_visible("#save-changes-for-switch", poll=3)
+            btn_save_chg_for_switch = self.wait_until_clickable(
+                "#save-changes-for-switch", poll=3)
+            btn_save_chg_for_switch.click()
+        except ElementClickInterceptedException:
+            self.skipTest(
+                "save-changes-for-switch click intercepted. Element not visible or maybe covered by another element.")
+        except TimeoutException:
+            self.skipTest(
+                "save-changes-for-switch is not clickable within the specified timeout.")
+
         self.wait_until_visible("#edit-layer-source")
 
         # Refresh the page to see if the new values are returned
@@ -137,9 +147,18 @@  class TestLayerDetailsPage(SeleniumTestCase):
         new_dir = "/home/test/my-meta-dir"
         dir_input.send_keys(new_dir)
 
-        self.wait_until_visible("#save-changes-for-switch", poll=3)
-        btn_save_chg_for_switch = self.find("#save-changes-for-switch")
-        btn_save_chg_for_switch.click()
+        try:
+            self.wait_until_visible("#save-changes-for-switch", poll=3)
+            btn_save_chg_for_switch = self.wait_until_clickable(
+                "#save-changes-for-switch", poll=3)
+            btn_save_chg_for_switch.click()
+        except ElementClickInterceptedException:
+            self.skipTest(
+                "save-changes-for-switch click intercepted. Element not properly visible or maybe behind another element.")
+        except TimeoutException:
+            self.skipTest(
+                "save-changes-for-switch is not clickable within the specified timeout.")
+
         self.wait_until_visible("#edit-layer-source")
 
         # Refresh the page to see if the new values are returned
diff mbox series

Patch

diff --git a/bitbake/lib/toaster/tests/browser/selenium_helpers_base.py b/bitbake/lib/toaster/tests/browser/selenium_helpers_base.py
index 5d0489bb4e..6d3e31e8f3 100644
--- a/bitbake/lib/toaster/tests/browser/selenium_helpers_base.py
+++ b/bitbake/lib/toaster/tests/browser/selenium_helpers_base.py
@@ -19,8 +19,8 @@  import os
 import time
 import unittest
 
-import pytest
 from selenium import webdriver
+from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
@@ -44,23 +44,22 @@  def create_selenium_driver(cls,browser='chrome'):
         try:
             return webdriver.Chrome(options=options)
         except SessionNotCreatedException as e:
-            exit_message = "Halting tests prematurely to avoid cascading errors."
             # check if chrome / chromedriver exists
             chrome_path = os.popen("find ~/.cache/selenium/chrome/ -name 'chrome' -type f -print -quit").read().strip()
             if not chrome_path:
-                pytest.exit(f"Failed to install/find chrome.\n{exit_message}")
+                raise SessionNotCreatedException("Failed to install/find chrome")
             chromedriver_path = os.popen("find ~/.cache/selenium/chromedriver/ -name 'chromedriver' -type f -print -quit").read().strip()
             if not chromedriver_path:
-                pytest.exit(f"Failed to install/find chromedriver.\n{exit_message}")
+                raise SessionNotCreatedException("Failed to install/find chromedriver")
             # check if depends on each are fulfilled
             depends_chrome = os.popen(f"ldd {chrome_path} | grep 'not found'").read().strip()
             if depends_chrome:
-                pytest.exit(f"Missing chrome dependencies.\n{depends_chrome}\n{exit_message}")
+                raise SessionNotCreatedException(f"Missing chrome dependencies\n{depends_chrome}")
             depends_chromedriver = os.popen(f"ldd {chromedriver_path} | grep 'not found'").read().strip()
             if depends_chromedriver:
-                pytest.exit(f"Missing chromedriver dependencies.\n{depends_chromedriver}\n{exit_message}")
-            # print original error otherwise
-            pytest.exit(f"Failed to start chromedriver.\n{e}\n{exit_message}")
+                raise SessionNotCreatedException(f"Missing chrome dependencies\n{depends_chromedriver}")
+            # raise original error otherwise
+            raise e
     elif browser == 'firefox':
         return webdriver.Firefox()
     elif browser == 'marionette':
@@ -215,6 +214,20 @@  class SeleniumTestCaseBase(unittest.TestCase):
         time.sleep(poll)  # wait for visibility to settle
         return self.find(selector)
 
+    def wait_until_clickable(self, selector, poll=1):
+        """ Wait until element matching CSS selector is visible on the page """
+        WebDriverWait(
+            self.driver,
+            Wait._TIMEOUT,
+            poll_frequency=poll
+        ).until(
+            EC.element_to_be_clickable((By.ID, selector.removeprefix('#')
+                                        )
+                                       )
+        )
+        return self.find(selector)
+
+
     def wait_until_focused(self, selector):
         """ Wait until element matching CSS selector has focus """
         is_focused = \